@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 # PODNAME: inst-abbr-ids.pl
 # ABSTRACT: Abbreviate seq ids in FASTA files (optimized)
-# CONTRIBUTOR: Valerian LUPO <valerian.lupo@doct.uliege.be>
+# CONTRIBUTOR: Valerian LUPO <valerian.lupo@uliege.be>
 
 use Modern::Perl '2011';
 use autodie;
@@ -112,7 +112,7 @@ inst-abbr-ids.pl - Abbreviate seq ids in FASTA files (optimized)
 
 =head1 VERSION
 
-version 0.250380
+version 0.251140
 
 =head1 USAGE
 
@@ -199,7 +199,7 @@ Denis BAURAIN <denis.baurain@uliege.be>
 
 =for stopwords Valerian LUPO
 
-Valerian LUPO <valerian.lupo@doct.uliege.be>
+Valerian LUPO <valerian.lupo@uliege.be>
 
 =head1 COPYRIGHT AND LICENSE
 
