@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 # PODNAME: inst-split-seqs.pl
 # ABSTRACT: Split sequences of FASTA files into shorter sequences (optimized)
-# CONTRIBUTOR: Valerian LUPO <valerian.lupo@doct.uliege.be>
+# CONTRIBUTOR: Valerian LUPO <valerian.lupo@uliege.be>
 
 use Modern::Perl '2011';
 use autodie;
@@ -52,7 +52,7 @@ inst-split-seqs.pl - Split sequences of FASTA files into shorter sequences (opti
 
 =head1 VERSION
 
-version 0.250380
+version 0.251140
 
 =head1 USAGE
 
@@ -115,7 +115,7 @@ Denis BAURAIN <denis.baurain@uliege.be>
 
 =for stopwords Valerian LUPO
 
-Valerian LUPO <valerian.lupo@doct.uliege.be>
+Valerian LUPO <valerian.lupo@uliege.be>
 
 =head1 COPYRIGHT AND LICENSE
 
